@@ -39,7 +39,7 @@ class UserUpdate(task_manager.Task):
 
 class FlavorList(task_manager.Task):
     def main(self, client):
-        return client.nova_client.flavors.list()
+        return client.nova_client.flavors.list(**self.args)
 
 
 class FlavorCreate(task_manager.Task):
@@ -52,6 +52,11 @@ class FlavorDelete(task_manager.Task):
         return client.nova_client.flavors.delete(**self.args)
 
 
+class FlavorGet(task_manager.Task):
+    def main(self, client):
+        return client.nova_client.flavors.get(**self.args)
+
+
 class ServerList(task_manager.Task):
     def main(self, client):
         return client.nova_client.servers.list(**self.args)
@@ -535,3 +540,23 @@ class IdentityDomainUpdate(task_manager.Task):
 class IdentityDomainDelete(task_manager.Task):
     def main(self, client):
         return client.keystone_client.domains.delete(**self.args)
+
+
+class DomainList(task_manager.Task):
+    def main(self, client):
+        return client.designate_client.domains.list()
+
+
+class DomainGet(task_manager.Task):
+    def main(self, client):
+        return client.designate_client.domains.get(**self.args)
+
+
+class RecordList(task_manager.Task):
+    def main(self, client):
+        return client.designate_client.records.list(**self.args)
+
+
+class RecordGet(task_manager.Task):
+    def main(self, client):
+        return client.designate_client.records.get(**self.args)
