@@ -193,3 +193,83 @@ def is_globally_routable_ipv4(ip):
             return False
 
     return True
+
+
+def normalize_nova_floating_ips(ips):
+    """Normalize the structure of Neutron floating IPs
+
+    Unfortunately, not all the Neutron floating_ip attributes are available
+    with Nova and not all Nova floating_ip attributes are available with
+    Neutron.
+    This function extract attributes that are common to Nova and Neutron
+    floating IP resource.
+    If the whole structure is needed inside shade, shade provides private
+    methods that returns "original" objects (e.g. _nova_allocate_floating_ip)
+
+    :param list ips: A list of Nova floating IPs.
+
+    :returns:
+        A list of normalized dicts with the following attributes::
+
+        [
+          {
+            "id": "this-is-a-floating-ip-id",
+            "fixed_ip_address": "192.0.2.10",
+            "floating_ip_address": "198.51.100.10",
+            "network": "this-is-a-net-or-pool-id",
+            "attached": True,
+            "status": "ACTIVE"
+          }, ...
+        ]
+
+    """
+    return [dict(
+        id=ip['id'],
+        fixed_ip_address=ip.get('fixed_ip'),
+        floating_ip_address=ip['ip'],
+        network=ip['pool'],
+        attached=(ip.get('instance_id') is not None and
+                  ip.get('instance_id') != ''),
+        status='ACTIVE'  # In neutrons terms, Nova floating IPs are always
+                         # ACTIVE
+    ) for ip in ips]
+
+
+def normalize_neutron_floating_ips(ips):
+    """Normalize the structure of Neutron floating IPs
+
+    Unfortunately, not all the Neutron floating_ip attributes are available
+    with Nova and not all Nova floating_ip attributes are available with
+    Neutron.
+    This function extract attributes that are common to Nova and Neutron
+    floating IP resource.
+    If the whole structure is needed inside shade, shade provides private
+    methods that returns "original" objects (e.g.
+    _neutron_allocate_floating_ip)
+
+    :param list ips: A list of Neutron floating IPs.
+
+    :returns:
+        A list of normalized dicts with the following attributes::
+
+        [
+          {
+            "id": "this-is-a-floating-ip-id",
+            "fixed_ip_address": "192.0.2.10",
+            "floating_ip_address": "198.51.100.10",
+            "network": "this-is-a-net-or-pool-id",
+            "attached": True,
+            "status": "ACTIVE"
+          }, ...
+        ]
+
+    """
+    return [dict(
+        id=ip['id'],
+        fixed_ip_address=ip.get('fixed_ip_address'),
+        floating_ip_address=ip['floating_ip_address'],
+        network=ip['floating_network_id'],
+        attached=(ip.get('port_id') is not None and
+                  ip.get('port_id') != ''),
+        status=ip['status']
+    ) for ip in ips]
