@@ -20,6 +20,7 @@ Tests for the `create_server` command.
 """
 
 from mock import patch, Mock
+import os_client_config
 from shade import meta
 from shade import OpenStackCloud
 from shade.exc import (OpenStackCloudException, OpenStackCloudTimeout)
@@ -30,7 +31,8 @@ class TestCreateServer(base.TestCase):
 
     def setUp(self):
         super(TestCreateServer, self).setUp()
-        self.client = OpenStackCloud("cloud", {})
+        config = os_client_config.OpenStackConfig()
+        self.client = OpenStackCloud(cloud_config=config.get_one_cloud())
 
     def test_create_server_with_create_exception(self):
         """
@@ -125,7 +127,8 @@ class TestCreateServer(base.TestCase):
         its status changes to "ACTIVE".
         """
         with patch("shade.OpenStackCloud"):
-            fake_server = fakes.FakeServer('', '', 'ACTIVE')
+            fake_server = fakes.FakeServer(
+                '', '', 'ACTIVE', addresses=dict(public='1.1.1.1'))
             config = {
                 "servers.create.return_value": fakes.FakeServer('', '',
                                                                 'ACTIVE'),
@@ -138,3 +141,23 @@ class TestCreateServer(base.TestCase):
                 self.assertEqual(
                     self.client.create_server(wait=True),
                     fake_server)
+
+    def test_create_server_no_addresses(self):
+        """
+        Test that create_server with a wait throws an exception if the
+        server doesn't have addresses.
+        """
+        with patch("shade.OpenStackCloud"):
+            fake_server = fakes.FakeServer('', '', 'ACTIVE')
+            config = {
+                "servers.create.return_value": fakes.FakeServer('', '',
+                                                                'ACTIVE'),
+                "servers.get.side_effect": [
+                    Mock(status="BUILD"), fake_server]
+            }
+            OpenStackCloud.nova_client = Mock(**config)
+            with patch.object(OpenStackCloud, "add_ips_to_server",
+                              return_value=fake_server):
+                self.assertRaises(
+                    OpenStackCloudException, self.client.create_server,
+                    wait=True)
