@@ -14,8 +14,10 @@
 # under the License.
 
 import mock
+import os_client_config
 from swiftclient import client as swift_client
 from swiftclient import service as swift_service
+from swiftclient import exceptions as swift_exc
 
 import shade
 from shade import exc
@@ -23,11 +25,12 @@ from shade import OpenStackCloud
 from shade.tests.unit import base
 
 
-class TestShade(base.TestCase):
+class TestObject(base.TestCase):
 
     def setUp(self):
-        super(TestShade, self).setUp()
-        self.cloud = OpenStackCloud('cloud', {})
+        super(TestObject, self).setUp()
+        config = os_client_config.OpenStackConfig()
+        self.cloud = OpenStackCloud(cloud_config=config.get_one_cloud())
 
     @mock.patch.object(swift_client, 'Connection')
     @mock.patch.object(shade.OpenStackCloud, 'auth_token',
@@ -41,6 +44,7 @@ class TestShade(base.TestCase):
             preauthurl='danzig',
             preauthtoken='yankee',
             auth_version='2',
+            timeout=None,
             os_options=dict(
                 object_storage_url='danzig',
                 auth_token='yankee',
@@ -81,3 +85,10 @@ class TestShade(base.TestCase):
         self.assertEqual(900, self.cloud.get_object_segment_size(900))
         self.assertEqual(1000, self.cloud.get_object_segment_size(1000))
         self.assertEqual(1000, self.cloud.get_object_segment_size(1100))
+
+    @mock.patch.object(shade.OpenStackCloud, 'swift_client')
+    def test_get_object_segment_size_http_412(self, swift_mock):
+        swift_mock.get_capabilities.side_effect = swift_exc.ClientException(
+            "Precondition failed", http_status=412)
+        self.assertEqual(shade.DEFAULT_OBJECT_SEGMENT_SIZE,
+                         self.cloud.get_object_segment_size(None))
